==> knative-model-6.3.1-sources.jar: io/fabric8/knative/eventing/v1/SubscriptionsAPIFilterFluent.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SubscriptionsAPIFilterFluent<A extends SubscriptionsAPIFilterFluent<A>> extends Fluent<A>{
  public A addToAll(Integer index,SubscriptionsAPIFilter item);
  public A setToAll(Integer index,SubscriptionsAPIFilter item);
  public A addToAll(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... items);
  public A addAllToAll(Collection<SubscriptionsAPIFilter> items);
  public A removeFromAll(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... items);
  public A removeAllFromAll(Collection<SubscriptionsAPIFilter> items);
  public A removeMatchingFromAll(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAll instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriptionsAPIFilter> getAll();
  public List<SubscriptionsAPIFilter> buildAll();
  public SubscriptionsAPIFilter buildAll(Integer index);
  public SubscriptionsAPIFilter buildFirstAll();
  public SubscriptionsAPIFilter buildLastAll();
  public SubscriptionsAPIFilter buildMatchingAll(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public Boolean hasMatchingAll(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public A withAll(List<SubscriptionsAPIFilter> all);
  public A withAll(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... all);
  public Boolean hasAll();
  public SubscriptionsAPIFilterFluent.AllNested<A> addNewAll();
  public SubscriptionsAPIFilterFluent.AllNested<A> addNewAllLike(SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.AllNested<A> setNewAllLike(Integer index,SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.AllNested<A> editAll(Integer index);
  public SubscriptionsAPIFilterFluent.AllNested<A> editFirstAll();
  public SubscriptionsAPIFilterFluent.AllNested<A> editLastAll();
  public SubscriptionsAPIFilterFluent.AllNested<A> editMatchingAll(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public A addToAny(Integer index,SubscriptionsAPIFilter item);
  public A setToAny(Integer index,SubscriptionsAPIFilter item);
  public A addToAny(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... items);
  public A addAllToAny(Collection<SubscriptionsAPIFilter> items);
  public A removeFromAny(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... items);
  public A removeAllFromAny(Collection<SubscriptionsAPIFilter> items);
  public A removeMatchingFromAny(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAny instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriptionsAPIFilter> getAny();
  public List<SubscriptionsAPIFilter> buildAny();
  public SubscriptionsAPIFilter buildAny(Integer index);
  public SubscriptionsAPIFilter buildFirstAny();
  public SubscriptionsAPIFilter buildLastAny();
  public SubscriptionsAPIFilter buildMatchingAny(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public Boolean hasMatchingAny(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public A withAny(List<SubscriptionsAPIFilter> any);
  public A withAny(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... any);
  public Boolean hasAny();
  public SubscriptionsAPIFilterFluent.AnyNested<A> addNewAny();
  public SubscriptionsAPIFilterFluent.AnyNested<A> addNewAnyLike(SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.AnyNested<A> setNewAnyLike(Integer index,SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.AnyNested<A> editAny(Integer index);
  public SubscriptionsAPIFilterFluent.AnyNested<A> editFirstAny();
  public SubscriptionsAPIFilterFluent.AnyNested<A> editLastAny();
  public SubscriptionsAPIFilterFluent.AnyNested<A> editMatchingAny(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public String getCesql();
  public A withCesql(String cesql);
  public Boolean hasCesql();
  public A addToExact(String key,String value);
  public A addToExact(Map<String,String> map);
  public A removeFromExact(String key);
  public A removeFromExact(Map<String,String> map);
  public Map<String,String> getExact();
  public <K,V>A withExact(Map<String,String> exact);
  public Boolean hasExact();
  
  /**
   * This method has been deprecated, please use method buildNot instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubscriptionsAPIFilter getNot();
  public SubscriptionsAPIFilter buildNot();
  public A withNot(SubscriptionsAPIFilter not);
  public Boolean hasNot();
  public SubscriptionsAPIFilterFluent.NotNested<A> withNewNot();
  public SubscriptionsAPIFilterFluent.NotNested<A> withNewNotLike(SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.NotNested<A> editNot();
  public SubscriptionsAPIFilterFluent.NotNested<A> editOrNewNot();
  public SubscriptionsAPIFilterFluent.NotNested<A> editOrNewNotLike(SubscriptionsAPIFilter item);
  public A addToPrefix(String key,String value);
  public A addToPrefix(Map<String,String> map);
  public A removeFromPrefix(String key);
  public A removeFromPrefix(Map<String,String> map);
  public Map<String,String> getPrefix();
  public <K,V>A withPrefix(Map<String,String> prefix);
  public Boolean hasPrefix();
  public A addToSuffix(String key,String value);
  public A addToSuffix(Map<String,String> map);
  public A removeFromSuffix(String key);
  public A removeFromSuffix(Map<String,String> map);
  public Map<String,String> getSuffix();
  public <K,V>A withSuffix(Map<String,String> suffix);
  public Boolean hasSuffix();
  public interface AllNested<N> extends Nested<N>,SubscriptionsAPIFilterFluent<SubscriptionsAPIFilterFluent.AllNested<N>>{
    public N and();
    public N endAll();
    
  }
  public interface AnyNested<N> extends Nested<N>,SubscriptionsAPIFilterFluent<SubscriptionsAPIFilterFluent.AnyNested<N>>{
    public N and();
    public N endAny();
    
  }
  public interface NotNested<N> extends Nested<N>,SubscriptionsAPIFilterFluent<SubscriptionsAPIFilterFluent.NotNested<N>>{
    public N and();
    public N endNot();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/v1/SubscriptionsAPIFilterFluent.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SubscriptionsAPIFilterFluent<A extends SubscriptionsAPIFilterFluent<A>> extends Fluent<A>{
  public A addToAll(int index,SubscriptionsAPIFilter item);
  public A setToAll(int index,SubscriptionsAPIFilter item);
  public A addToAll(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... items);
  public A addAllToAll(Collection<SubscriptionsAPIFilter> items);
  public A removeFromAll(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... items);
  public A removeAllFromAll(Collection<SubscriptionsAPIFilter> items);
  public A removeMatchingFromAll(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAll instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriptionsAPIFilter> getAll();
  public List<SubscriptionsAPIFilter> buildAll();
  public SubscriptionsAPIFilter buildAll(int index);
  public SubscriptionsAPIFilter buildFirstAll();
  public SubscriptionsAPIFilter buildLastAll();
  public SubscriptionsAPIFilter buildMatchingAll(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public Boolean hasMatchingAll(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public A withAll(List<SubscriptionsAPIFilter> all);
  public A withAll(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... all);
  public Boolean hasAll();
  public SubscriptionsAPIFilterFluent.AllNested<A> addNewAll();
  public SubscriptionsAPIFilterFluent.AllNested<A> addNewAllLike(SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.AllNested<A> setNewAllLike(int index,SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.AllNested<A> editAll(int index);
  public SubscriptionsAPIFilterFluent.AllNested<A> editFirstAll();
  public SubscriptionsAPIFilterFluent.AllNested<A> editLastAll();
  public SubscriptionsAPIFilterFluent.AllNested<A> editMatchingAll(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public A addToAny(int index,SubscriptionsAPIFilter item);
  public A setToAny(int index,SubscriptionsAPIFilter item);
  public A addToAny(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... items);
  public A addAllToAny(Collection<SubscriptionsAPIFilter> items);
  public A removeFromAny(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... items);
  public A removeAllFromAny(Collection<SubscriptionsAPIFilter> items);
  public A removeMatchingFromAny(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAny instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriptionsAPIFilter> getAny();
  public List<SubscriptionsAPIFilter> buildAny();
  public SubscriptionsAPIFilter buildAny(int index);
  public SubscriptionsAPIFilter buildFirstAny();
  public SubscriptionsAPIFilter buildLastAny();
  public SubscriptionsAPIFilter buildMatchingAny(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public Boolean hasMatchingAny(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public A withAny(List<SubscriptionsAPIFilter> any);
  public A withAny(io.fabric8.knative.eventing.v1.SubscriptionsAPIFilter... any);
  public Boolean hasAny();
  public SubscriptionsAPIFilterFluent.AnyNested<A> addNewAny();
  public SubscriptionsAPIFilterFluent.AnyNested<A> addNewAnyLike(SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.AnyNested<A> setNewAnyLike(int index,SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.AnyNested<A> editAny(int index);
  public SubscriptionsAPIFilterFluent.AnyNested<A> editFirstAny();
  public SubscriptionsAPIFilterFluent.AnyNested<A> editLastAny();
  public SubscriptionsAPIFilterFluent.AnyNested<A> editMatchingAny(Predicate<SubscriptionsAPIFilterBuilder> predicate);
  public String getCesql();
  public A withCesql(String cesql);
  public Boolean hasCesql();
  public A addToExact(String key,String value);
  public A addToExact(Map<String,String> map);
  public A removeFromExact(String key);
  public A removeFromExact(Map<String,String> map);
  public Map<String,String> getExact();
  public <K,V>A withExact(Map<String,String> exact);
  public Boolean hasExact();
  
  /**
   * This method has been deprecated, please use method buildNot instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubscriptionsAPIFilter getNot();
  public SubscriptionsAPIFilter buildNot();
  public A withNot(SubscriptionsAPIFilter not);
  public Boolean hasNot();
  public SubscriptionsAPIFilterFluent.NotNested<A> withNewNot();
  public SubscriptionsAPIFilterFluent.NotNested<A> withNewNotLike(SubscriptionsAPIFilter item);
  public SubscriptionsAPIFilterFluent.NotNested<A> editNot();
  public SubscriptionsAPIFilterFluent.NotNested<A> editOrNewNot();
  public SubscriptionsAPIFilterFluent.NotNested<A> editOrNewNotLike(SubscriptionsAPIFilter item);
  public A addToPrefix(String key,String value);
  public A addToPrefix(Map<String,String> map);
  public A removeFromPrefix(String key);
  public A removeFromPrefix(Map<String,String> map);
  public Map<String,String> getPrefix();
  public <K,V>A withPrefix(Map<String,String> prefix);
  public Boolean hasPrefix();
  public A addToSuffix(String key,String value);
  public A addToSuffix(Map<String,String> map);
  public A removeFromSuffix(String key);
  public A removeFromSuffix(Map<String,String> map);
  public Map<String,String> getSuffix();
  public <K,V>A withSuffix(Map<String,String> suffix);
  public Boolean hasSuffix();
  public interface AllNested<N> extends Nested<N>,SubscriptionsAPIFilterFluent<SubscriptionsAPIFilterFluent.AllNested<N>>{
    public N and();
    public N endAll();
    
  }
  public interface AnyNested<N> extends Nested<N>,SubscriptionsAPIFilterFluent<SubscriptionsAPIFilterFluent.AnyNested<N>>{
    public N and();
    public N endAny();
    
  }
  public interface NotNested<N> extends Nested<N>,SubscriptionsAPIFilterFluent<SubscriptionsAPIFilterFluent.NotNested<N>>{
    public N and();
    public N endNot();
    
  }
  
}
